==> zio-aws-ec2_2.12-5.20.17.2-sources.jar: zio/aws/ec2/model/DescribeInstanceTypeOfferingsRequest.scala <==
package zio.aws.ec2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{NextToken, DITOMaxResults}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeInstanceTypeOfferingsRequest(
    locationType: Optional[zio.aws.ec2.model.LocationType] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    maxResults: Optional[DITOMaxResults] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeInstanceTypeOfferingsRequest = {
    import DescribeInstanceTypeOfferingsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeInstanceTypeOfferingsRequest
      .builder()
      .optionallyWith(locationType.map(value => value.unwrap))(_.locationType)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value => DITOMaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeInstanceTypeOfferingsRequest.ReadOnly =
    zio.aws.ec2.model.DescribeInstanceTypeOfferingsRequest.wrap(buildAwsValue())
}
object DescribeInstanceTypeOfferingsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeInstanceTypeOfferingsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeInstanceTypeOfferingsRequest =
      zio.aws.ec2.model.DescribeInstanceTypeOfferingsRequest(
        locationType.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def locationType: Optional[zio.aws.ec2.model.LocationType]
    def filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Optional[DITOMaxResults]
    def nextToken: Optional[NextToken]
    def getLocationType: ZIO[Any, AwsError, zio.aws.ec2.model.LocationType] =
      AwsError.unwrapOptionField("locationType", locationType)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, DITOMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeInstanceTypeOfferingsRequest
  ) extends zio.aws.ec2.model.DescribeInstanceTypeOfferingsRequest.ReadOnly {
    override val locationType: Optional[zio.aws.ec2.model.LocationType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.locationType())
        .map(value => zio.aws.ec2.model.LocationType.wrap(value))
    override val filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Optional[DITOMaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.ec2.model.primitives.DITOMaxResults(value))
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.ec2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeInstanceTypeOfferingsRequest
  ): zio.aws.ec2.model.DescribeInstanceTypeOfferingsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/DescribeInstanceTypeOfferingsRequest.scala <==
package zio.aws.ec2.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ec2.model.primitives.{NextToken, DITOMaxResults}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeInstanceTypeOfferingsRequest(
    dryRun: Optional[Boolean] = Optional.Absent,
    locationType: Optional[zio.aws.ec2.model.LocationType] = Optional.Absent,
    filters: Optional[Iterable[zio.aws.ec2.model.Filter]] = Optional.Absent,
    maxResults: Optional[DITOMaxResults] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.DescribeInstanceTypeOfferingsRequest = {
    import DescribeInstanceTypeOfferingsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.DescribeInstanceTypeOfferingsRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .optionallyWith(locationType.map(value => value.unwrap))(_.locationType)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value => DITOMaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.DescribeInstanceTypeOfferingsRequest.ReadOnly =
    zio.aws.ec2.model.DescribeInstanceTypeOfferingsRequest.wrap(buildAwsValue())
}
object DescribeInstanceTypeOfferingsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.DescribeInstanceTypeOfferingsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.DescribeInstanceTypeOfferingsRequest =
      zio.aws.ec2.model.DescribeInstanceTypeOfferingsRequest(
        dryRun.map(value => value),
        locationType.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def dryRun: Optional[Boolean]
    def locationType: Optional[zio.aws.ec2.model.LocationType]
    def filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]]
    def maxResults: Optional[DITOMaxResults]
    def nextToken: Optional[NextToken]
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getLocationType: ZIO[Any, AwsError, zio.aws.ec2.model.LocationType] =
      AwsError.unwrapOptionField("locationType", locationType)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, DITOMaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.DescribeInstanceTypeOfferingsRequest
  ) extends zio.aws.ec2.model.DescribeInstanceTypeOfferingsRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val locationType: Optional[zio.aws.ec2.model.LocationType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.locationType())
        .map(value => zio.aws.ec2.model.LocationType.wrap(value))
    override val filters: Optional[List[zio.aws.ec2.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Optional[DITOMaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.ec2.model.primitives.DITOMaxResults(value))
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.ec2.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.DescribeInstanceTypeOfferingsRequest
  ): zio.aws.ec2.model.DescribeInstanceTypeOfferingsRequest.ReadOnly =
    new Wrapper(impl)
}
